==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Pluginet %1 er ikke kompatibelt med systemet.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-indstillinger</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Sluk</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Tænd</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-indstillinger</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Tilføj tastaturlayout</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dato og klokkeslæt</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-timers klokkeslæt</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-timers klokkeslæt</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Tidsindstillinger</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Aktivér netværk</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Deaktivér netværk</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netværksindstillinger</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Er du sikker på, at du vil tømme %1 punkter?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Handlingen kan ikke gendannes</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Ukendt enhed</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Ukendt volumen</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Afmonter alle</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Programstarter</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Fashion-tilstand</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Effektiv tilstand</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Øverst</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Nederst</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Hold vist</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Hold skjult</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Smart skjul</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tilstand</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Placering</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Multitaskingvisning</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Fjern fra dok</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Deaktivér kablet forbindelse</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Aktivér kablet forbindelse</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Deaktivér trådløs forbindelse</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Aktivér trådløs forbindelse</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Deaktivér netværk</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Aktivér netværk</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netværksindstillinger</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Enhed deaktiveret</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Trådløs forbindelse: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Kablet forbindelse: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ikke tilsluttet</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Opretter forbindelse</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Tilsluttet men ingen internetadgang</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netværkskablet er frakoblet</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Trådløst netværk</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kablet netværk</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Netværk</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kablet netværk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kablet netværk %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Strøm</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Strømindstillinger</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapacitet %1, %2 minutter tilbage</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapacitet %1, %2 timer %3 minutter tilbage</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Oplader %1, %2 minutter til fuldt</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Oplader %1, %2 timer %3 minutter til fuldt</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Opladet</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Oplader %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Vis skrivebord</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Fjern fra dok</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Strøm</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Hvile</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lås</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Log ud</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Skift konto</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Strømindstillinger</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Enhed</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Lyd til</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Lydløs</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Lydindstillinger</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Lydstyrke %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Lyd</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Papirkurv</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Papirkurv - %1 fil</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Papirkurv - %1 filer</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Tomt</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Systembakke</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Trådløst netværk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Trådløst netværk %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.73.orig.tar.xz: dde-dock-5.5.73/translations/dde-dock_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="da">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Pluginet %1 er ikke kompatibelt med systemet.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Sluk</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Tænd</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-indstillinger</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Sluk</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Tænd</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-indstillinger</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Tilføj tastaturlayout</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dato og klokkeslæt</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-timers klokkeslæt</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-timers klokkeslæt</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Tidsindstillinger</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Er du sikker på, at du vil tømme %1 punkter?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Handlingen kan ikke gendannes</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Ukendt enhed</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Ukendt volumen</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Afmonter alle</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Programstarter</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Fashion-tilstand</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Effektiv tilstand</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Øverst</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Nederst</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Hold vist</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Hold skjult</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Smart skjul</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tilstand</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Placering</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Flere skærme</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Moderne tilstand</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Effektiv visning</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tilstand</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Øverst</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Nederst</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Placering</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Hold skjult</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Smart skjuling</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Lille</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Stor</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Multitaskingvisning</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Fjern fra dok</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Strøm</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Strømindstillinger</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapacitet %1, %2 minutter tilbage</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapacitet %1, %2 timer %3 minutter tilbage</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Oplader %1, %2 minutter til fuldt</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Oplader %1, %2 timer %3 minutter til fuldt</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Oplader %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dok</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Vis skrivebord</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Fjern fra dok</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Strøm</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Hvile</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lås</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Log ud</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Skift konto</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Strømindstillinger</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Enhed</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Lyd til</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Lydløs</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Lydindstillinger</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Lydstyrke %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Lyd</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Papirkurv</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Papirkurv - %1 fil</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Papirkurv - %1 filer</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Flyt til papirkurv</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Tomt</translation>
    </message>
</context>
</TS>
